==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/invocation/impl/FunctionInvocationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.invocation.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.FunctionInvocation;
import io.ciera.tool.sql.ooaofooa.invocation.FunctionInvocationSet;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;

import java.util.Arrays;
import java.util.List;


public class FunctionInvocationSetImpl extends InstanceSet<FunctionInvocationSet,FunctionInvocation> implements FunctionInvocationSet {

    // attributes
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setSync_ID( ref_Sync_ID );
    }
    @Override
    public void setFunctionNameColumn( int m_functionNameColumn ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setFunctionNameColumn( m_functionNameColumn );
    }
    @Override
    public void setFunctionNameLineNumber( int m_functionNameLineNumber ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setFunctionNameLineNumber( m_functionNameLineNumber );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( FunctionInvocation functioninvocation : this ) act_smtset.add( functioninvocation.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_PARSet R669_takes_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( FunctionInvocation functioninvocation : this ) v_parset.addAll( functioninvocation.R669_takes_V_PAR() );
        return v_parset;
    }
    @Override
    public S_SYNCSet R675_is_an_invocation_of_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionInvocation functioninvocation : this ) s_syncset.add( functioninvocation.R675_is_an_invocation_of_S_SYNC() );
        return s_syncset;
    }


    @Override
    public FunctionInvocation nullElement() {
        return FunctionInvocationImpl.EMPTY_FUNCTIONINVOCATION;
    }

    @Override
    public FunctionInvocationSet emptySet() {
      return new FunctionInvocationSetImpl();
    }

    @Override
    public FunctionInvocationSet value() {
        return this;
    }

    @Override
    public List<FunctionInvocation> elements() {
        return Arrays.asList(toArray(new FunctionInvocation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/invocation/impl/FunctionInvocationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.invocation.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.S_SYNCSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.S_SYNCSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.FunctionInvocation;
import io.ciera.tool.sql.ooaofooa.invocation.FunctionInvocationSet;
import io.ciera.tool.sql.ooaofooa.value.V_PARSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_PARSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class FunctionInvocationSetImpl extends InstanceSet<FunctionInvocationSet,FunctionInvocation> implements FunctionInvocationSet {

    public FunctionInvocationSetImpl() {
    }

    public FunctionInvocationSetImpl(Comparator<? super FunctionInvocation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setFunctionNameColumn( int m_functionNameColumn ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setFunctionNameColumn( m_functionNameColumn );
    }
    @Override
    public void setFunctionNameLineNumber( int m_functionNameLineNumber ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setFunctionNameLineNumber( m_functionNameLineNumber );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setSync_ID( UniqueId ref_Sync_ID ) throws XtumlException {
        for ( FunctionInvocation functioninvocation : this ) functioninvocation.setSync_ID( ref_Sync_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( FunctionInvocation functioninvocation : this ) act_smtset.add( functioninvocation.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public V_PARSet R669_takes_V_PAR() throws XtumlException {
        V_PARSet v_parset = new V_PARSetImpl();
        for ( FunctionInvocation functioninvocation : this ) v_parset.addAll( functioninvocation.R669_takes_V_PAR() );
        return v_parset;
    }
    @Override
    public S_SYNCSet R675_is_an_invocation_of_S_SYNC() throws XtumlException {
        S_SYNCSet s_syncset = new S_SYNCSetImpl();
        for ( FunctionInvocation functioninvocation : this ) s_syncset.add( functioninvocation.R675_is_an_invocation_of_S_SYNC() );
        return s_syncset;
    }


    @Override
    public FunctionInvocation nullElement() {
        return FunctionInvocationImpl.EMPTY_FUNCTIONINVOCATION;
    }

    @Override
    public FunctionInvocationSet emptySet() {
      return new FunctionInvocationSetImpl();
    }

    @Override
    public FunctionInvocationSet emptySet(Comparator<? super FunctionInvocation> comp) {
      return new FunctionInvocationSetImpl(comp);
    }

    @Override
    public FunctionInvocationSet value() {
        return this;
    }

    @Override
    public List<FunctionInvocation> elements() {
        return Arrays.asList(toArray(new FunctionInvocation[0]));
    }

}
